@@ -622,7 +622,7 @@ gnc_prefs_move_grid_entry (GtkWidget *child,
 
 
 /** At dialog creation time, this function will be called once per
- *  adds-in.  It performs the work of adding the page into the main
+ *  add-in.  It performs the work of adding the page into the main
  *  dialog.  It handles both the case of a full page being added to
  *  the dialog, and a partial page being added.
  *
@@ -1202,7 +1202,7 @@ gnc_preferences_response_cb (GtkDialog *dialog, gint response, GtkDialog *unused
     switch (response)
     {
     case GTK_RESPONSE_HELP:
-        gnc_gnome_help (GTK_WINDOW(dialog), HF_HELP, HL_GLOBPREFS);
+        gnc_gnome_help (GTK_WINDOW(dialog), DF_MANUAL, DL_GLOBPREFS);
         break;
 
     case GTK_RESPONSE_DELETE_EVENT:
@@ -1376,22 +1376,6 @@ gnc_preferences_dialog_create (GtkWindow *parent)
     /* parent */
     gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(parent));
 
-#ifndef REGISTER2_ENABLED
-    /* Hide preferences that are related to register2 */
-    box = GTK_WIDGET(gtk_builder_get_object (builder, "label14"));
-    gtk_widget_hide (box);
-    box = GTK_WIDGET(gtk_builder_get_object (builder, "pref/general.register/key-length"));
-    gtk_widget_hide (box);
-    box = GTK_WIDGET(gtk_builder_get_object (builder, "pref/general.register/show-extra-dates"));
-    gtk_widget_hide (box);
-    box = GTK_WIDGET(gtk_builder_get_object (builder, "pref/general.register/show-calendar-buttons"));
-    gtk_widget_hide (box);
-    box = GTK_WIDGET(gtk_builder_get_object (builder, "pref/general.register/selection-to-blank-on-expand"));
-    gtk_widget_hide (box);
-    box = GTK_WIDGET(gtk_builder_get_object (builder, "pref/general.register/show-extra-dates-on-selection"));
-    gtk_widget_hide (box);
-#endif
-
     label = GTK_WIDGET(gtk_builder_get_object (builder, "sample_account"));
     g_object_set_data (G_OBJECT(dialog), "sample_account", label);
 
