@@ -298,7 +298,7 @@ gnc_window_adjust_for_screen(GtkWindow * window)
 }
 
 /********************************************************************\
- * Sets the alignament of a Label Widget, GTK3 version specific.    *
+ * Sets the alignment of a Label Widget, GTK3 version specific.    *
  *                                                                  *
  * Args: widget - the label widget to set alignment on              *
  *       xalign - x alignment                                       *
@@ -431,7 +431,7 @@ gnc_gdate_in_valid_range (GDate *test_date, gboolean warn)
 
     if (warn && !ret)
     {
-            // Transators: Use your locale date format here!
+            // Translators: Use your locale date format here!
         gchar *dialog_msg = _("The entered date is out of the range "
                   "01/01/1400 - 31/12/9999, resetting to this year");
         gchar *dialog_title = _("Date out of range");
@@ -821,51 +821,6 @@ gnc_new_book_option_display (GtkWidget *parent)
     return TRUE;
 }
 
-/* This function returns a widget for selecting a cost policy
- */
-GtkWidget *
-gnc_cost_policy_select_new (void)
-{
-    GtkWidget *cost_policy_widget = NULL;
-    GList *list_of_policies = NULL;
-
-    list_of_policies = gnc_get_valid_policy_list();
-
-    g_return_val_if_fail(g_list_length (list_of_policies) >= 0, NULL);
-    if (list_of_policies)
-    {
-        GtkListStore *store = gtk_list_store_new (1, G_TYPE_STRING);
-        GtkTreeIter  iter;
-        GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
-        const char *description;
-        GList *l = NULL;
-
-        /* Add values to the list store, entry and tooltip */
-        for (l = list_of_policies; l != NULL; l = l->next)
-        {
-            GNCPolicy *pcy = l->data;
-            description = PolicyGetDescription (pcy);
-
-            gtk_list_store_append (store, &iter);
-            gtk_list_store_set (store, &iter,
-                    0, (description && *description) ? _(description) : "",
-                    -1);
-        }
-        g_list_free (list_of_policies);
-        /* Create the new Combo with the store */
-        cost_policy_widget = gtk_combo_box_new_with_model (GTK_TREE_MODEL(store));
-
-        gtk_cell_layout_pack_start (GTK_CELL_LAYOUT(cost_policy_widget), renderer, TRUE);
-        gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT(cost_policy_widget),
-                                       renderer, "text", 0);
-        g_object_unref (store);
-    }
-    return cost_policy_widget;
-}
-
-/* This function returns a string for the CSS 'gnc-class-negative-numbers' class,
- * the returned string must be freed
- */
 gchar*
 gnc_get_negative_color (void)
 {
@@ -877,3 +832,22 @@ gnc_get_negative_color (void)
 
     return gdk_rgba_to_string (&color);
 }
+
+void
+gnc_owner_window_set_title (GtkWindow *window, const char *header,
+                            GtkWidget *owner_entry, GtkWidget *id_entry)
+{
+    const char *name = gtk_entry_get_text (GTK_ENTRY (owner_entry));
+    if (!name || *name == '\0')
+        name = _("<No name>");
+
+    const char *id = gtk_entry_get_text (GTK_ENTRY (id_entry));
+
+    char *title = (id && *id) ?
+        g_strdup_printf ("%s - %s (%s)", header, name, id) :
+        g_strdup_printf ("%s - %s", header, name);
+
+    gtk_window_set_title (window, title);
+
+    g_free (title);
+}
