@@ -57,8 +57,7 @@ static guint gnc_frequency_signals[LAST_SIGNAL] = { 0 };
 
 /** Private Prototypes ********************/
 
-static void gnc_frequency_class_init( GncFrequencyClass *klass );
-static void gnc_frequency_class_destroy( GtkWidget *widget );
+static void gnc_frequency_destroy( GtkWidget *widget );
 
 static void freq_combo_changed( GtkComboBox *b, gpointer d );
 static void start_date_changed( GNCDateEdit *gde, gpointer d );
@@ -71,8 +70,6 @@ static void semimonthly_sel_changed( GtkButton *b, gpointer d );
 
 /** Static Inits ********************/
 
-static GObjectClass *parent_class = NULL;
-
 enum
 {
     PAGE_NONE = 0,
@@ -83,17 +80,6 @@ enum
     PAGE_MONTHLY
 };
 
-static const struct pageDataTuple PAGES[] =
-{
-    { PAGE_NONE,         UIFREQ_NONE,         "None" },
-    { PAGE_ONCE,         UIFREQ_ONCE,         "Once" },
-    { PAGE_DAILY,        UIFREQ_DAILY,        "Daily" },
-    { PAGE_WEEKLY,       UIFREQ_WEEKLY,       "Weekly" },
-    { PAGE_SEMI_MONTHLY, UIFREQ_SEMI_MONTHLY, "Semi-Monthly" },
-    { PAGE_MONTHLY,      UIFREQ_MONTHLY,      "Monthly" },
-    { 0, 0, 0 }
-};
-
 static const char *CHECKBOX_NAMES[] =
 {
     "wd_check_sun",
@@ -108,33 +94,23 @@ static const char *CHECKBOX_NAMES[] =
 
 /** Implementations ********************/
 
-GType
-gnc_frequency_get_type()
+/**
+ * A GncFrequency is a VBox containing a scrollable GtkNotebook [and other
+ * widgets] which allows the user to specify the frequency [of a scheduled
+ * transaction or budgeting category, for instance], manipulating a FreqSpec
+ * object in the process.
+ **/
+typedef struct _GncFrequency
 {
-    static GType gncfreq_type = 0;
-    if (gncfreq_type == 0)
-    {
-        static GTypeInfo gncfreq_info =
-        {
-            sizeof(GncFrequencyClass),
-            NULL,
-            NULL,
-            (GClassInitFunc)gnc_frequency_class_init,
-            NULL,
-            NULL,
-            sizeof(GncFrequency),
-            0,
-            (GInstanceInitFunc)gnc_frequency_init
-        };
-
-        gncfreq_type = g_type_register_static (GTK_TYPE_BOX,
-                                               "GncFrequency",
-                                               &gncfreq_info, 0);
-    }
-
-    return gncfreq_type;
-}
+    GtkBox	     widget;
+    GtkBox          *vb;
+    GtkNotebook     *nb;
+    GtkComboBox     *freqComboBox;
+    GNCDateEdit     *startDate;
+    GtkBuilder      *builder;
+} GncFrequency;
 
+G_DEFINE_TYPE (GncFrequency, gnc_frequency, GTK_TYPE_BOX)
 
 static void
 gnc_frequency_class_init( GncFrequencyClass *klass )
@@ -142,8 +118,6 @@ gnc_frequency_class_init( GncFrequencyClass *klass )
     GObjectClass *object_class;
     GtkWidgetClass *gtkwidget_class;
 
-    parent_class = g_type_class_peek_parent (klass);
-
     object_class = G_OBJECT_CLASS (klass);
     gtkwidget_class = GTK_WIDGET_CLASS (klass);
 
@@ -151,7 +125,7 @@ gnc_frequency_class_init( GncFrequencyClass *klass )
         g_signal_new ("changed",
                       G_OBJECT_CLASS_TYPE (object_class),
                       G_SIGNAL_RUN_FIRST,
-                      G_STRUCT_OFFSET (GncFrequencyClass, changed),
+                      0,
                       NULL,
                       NULL,
                       g_cclosure_marshal_VOID__VOID,
@@ -159,11 +133,11 @@ gnc_frequency_class_init( GncFrequencyClass *klass )
                       0);
 
     /* GtkWidget signals */
-    gtkwidget_class->destroy = gnc_frequency_class_destroy;
+    gtkwidget_class->destroy = gnc_frequency_destroy;
 }
 
 
-void
+static void
 gnc_frequency_init(GncFrequency *gf)
 {
     int i;
@@ -288,7 +262,7 @@ gnc_frequency_init(GncFrequency *gf)
  *  @internal
  */
 static void
-gnc_frequency_class_destroy (GtkWidget *widget)
+gnc_frequency_destroy (GtkWidget *widget)
 {
     GncFrequency *gf;
 
@@ -305,8 +279,7 @@ gnc_frequency_class_destroy (GtkWidget *widget)
         gf->builder = NULL;
     }
 
-    if (GTK_WIDGET_CLASS (parent_class)->destroy)
-        GTK_WIDGET_CLASS (parent_class)->destroy (widget);
+    GTK_WIDGET_CLASS (gnc_frequency_parent_class)->destroy (widget);
     LEAVE(" ");
 }
 
