@@ -196,7 +196,7 @@ gnc_plugin_remove_from_window (GncPlugin *plugin,
     /*
      * Update window to remove UI items
      */
-    if (klass->actions_name && !window->just_plugin_prefs)
+    if (klass->actions_name && !gnc_main_window_just_plugin_prefs (window))
     {
         DEBUG ("%s: %d actions to unmerge",
                klass->actions_name, (klass->n_actions));
