@@ -23,7 +23,7 @@
     @{ */
 
 /** @defgroup Dialogs Dialogs */
-/** @defgroup Druids Druids */
+/** @defgroup Assistants Assistants */
 
 /** @} */
 
@@ -37,46 +37,50 @@
 #include "gnc-pricedb.h"
 #include <gtk/gtk.h>
 
-
-/** Help Files ******************************************************/
-#ifdef G_OS_WIN32
-#    define HF_GUIDE         "gnucash-guide.chm"
-#    define HF_HELP          "gnucash-help.chm"
-#elif defined MAC_INTEGRATION
-#    define HF_GUIDE         "GnuCash Guide"
-#    define HF_HELP          "GnuCash Help"
-#else
-#    define HF_GUIDE         "gnucash-guide"
-#    define HF_HELP          "gnucash-help"
+#ifdef __cplusplus
+extern "C" {
 #endif
 
-/** Links in the Help Files *****************************************/
-#define HL_USAGE_BSNSS       "busnss-ar-setup1"
-#define HL_USAGE_INVOICE     "busnss-ar-invoices1"
-#define HL_USAGE_VOUCHER     "busnss-emply-newvchr"
-#define HL_USAGE_BILL        "busnss-ap-bills1"
-#define HL_USAGE_CUSTOMER    "busnss-ar-customers1"
-#define HL_USAGE_VENDOR      "busnss-ap-vendors1"
-#define HL_USAGE_EMPLOYEE    "busnss-emply"
-#define HL_USAGE_JOB         "busnss-ar-jobs1"
-#define HL_ACC               "acct-create"
-#define HL_ACCEDIT           "acct-edit"
-#define HL_COMMODITY         "tool-commodity"
-#define HL_FIND_TRANSACTIONS "tool-find"
-#define HL_FIN_CALC          "tool-calc"
-#define HL_PRICE_DB          "tool-price"
-#define HL_PRICE_EDIT        "tool-price-manual"
-#define HL_GLOBPREFS         "set-prefs"
-#define HL_PRINTCHECK        "print-check"
-#define HL_RECNWIN           "acct-reconcile"
-#define HL_SXEDITOR          "trans-sched"
-#define HL_SX_SLR            "trans-sched-slr"
-#define HL_BOOK_OPTIONS      "book-options"
-#define HL_STYLE_SHEET       "change-style"
-#define HL_CLOSE_BOOK        "tool-close-book"
-#define HL_USAGE_CUSTOMREP   "report-saving"
-#define HL_IMPORT_BC         "busnss-imp-bills-invoices"
-#define HL_IMPORT_CUST       "busnss-imp-customer-vendor"
+
+/** Documentation references ****************************************/
+#ifdef G_OS_WIN32
+#    define DF_GUIDE         "gnucash-guide.chm"
+#    define DF_MANUAL        "gnucash-manual.chm"
+#elif defined MAC_INTEGRATION
+#    define DF_GUIDE         "GnuCash Guide"
+#    define DF_MANUAL        "GnuCash Manual"
+#else
+#    define DF_GUIDE         "gnucash-guide"
+#    define DF_MANUAL        "gnucash-manual"
+#endif
+
+/** Links in the Manual *********************************************/
+#define DL_USAGE_BSNSS       "busnss-ar-setup1"
+#define DL_USAGE_INVOICE     "busnss-ar-invoices1"
+#define DL_USAGE_VOUCHER     "busnss-emply-newvchr"
+#define DL_USAGE_BILL        "busnss-ap-bills1"
+#define DL_USAGE_CUSTOMER    "busnss-ar-customers1"
+#define DL_USAGE_VENDOR      "busnss-ap-vendors1"
+#define DL_USAGE_EMPLOYEE    "busnss-emply"
+#define DL_USAGE_JOB         "busnss-ar-jobs1"
+#define DL_ACC               "acct-create"
+#define DL_ACCEDIT           "acct-edit"
+#define DL_COMMODITY         "tool-commodity"
+#define DL_FIND_TRANSACTIONS "tool-find"
+#define DL_FIN_CALC          "tool-calc"
+#define DL_PRICE_DB          "tool-price"
+#define DL_PRICE_EDIT        "tool-price-manual"
+#define DL_GLOBPREFS         "set-prefs"
+#define DL_PRINTCHECK        "print-check"
+#define DL_RECNWIN           "acct-reconcile"
+#define DL_SXEDITOR          "trans-sched"
+#define DL_SX_SLR            "trans-sched-slr"
+#define DL_BOOK_OPTIONS      "book-options"
+#define DL_STYLE_SHEET       "change-style"
+#define DL_CLOSE_BOOK        "tool-close-book"
+#define DL_USAGE_CUSTOMREP   "report-saving"
+#define DL_IMPORT_BC         "busnss-imp-bills-invoices"
+#define DL_IMPORT_CUST       "busnss-imp-customer-vendor"
 
 /* GTK Windows - Common Response Codes */
 
@@ -191,5 +195,9 @@ GtkWindow *gnc_ui_get_main_window (GtkWidget *widget);
 void gnc_set_busy_cursor(GtkWidget *w, gboolean update_now);
 void gnc_unset_busy_cursor(GtkWidget *w);
 
+#ifdef __cplusplus
+}
+#endif
+
 
 #endif
