@@ -274,17 +274,26 @@ gnc_stock_split_assistant_details_complete (GtkAssistant *assistant,
         gpointer user_data)
 {
     StockSplitInfo *info = user_data;
+    GNCPrintAmountInfo print_info;
+    gnc_commodity *currency;
     gnc_numeric amount;
     gint result;
 
-    result = gnc_amount_edit_expr_is_valid (GNC_AMOUNT_EDIT (info->distribution_edit), &amount, TRUE);
+    result = gnc_amount_edit_expr_is_valid (GNC_AMOUNT_EDIT (info->distribution_edit),
+                                            &amount, TRUE, NULL);
     if ( result != 0)
         return FALSE; /* Parsing error or field is empty */
 
     if (gnc_numeric_zero_p (amount))
         return FALSE; /* field value is 0 */
 
-    result = gnc_amount_edit_expr_is_valid (GNC_AMOUNT_EDIT (info->price_edit), &amount, TRUE);
+    currency = gnc_currency_edit_get_currency (GNC_CURRENCY_EDIT(info->price_currency_edit));
+    print_info = gnc_commodity_print_info (currency, FALSE);
+    gnc_amount_edit_set_print_info (GNC_AMOUNT_EDIT (info->price_edit), print_info);
+    gnc_amount_edit_set_fraction (GNC_AMOUNT_EDIT (info->price_edit), 0);
+
+    result = gnc_amount_edit_expr_is_valid (GNC_AMOUNT_EDIT(info->price_edit),
+                                            &amount, TRUE, NULL);
     if (result == -1)
         return TRUE; /* Optional field is empty */
     else if ( result > 0)
@@ -305,7 +314,7 @@ gnc_stock_split_assistant_cash_complete (GtkAssistant *assistant,
     gint result;
     Account *account;
 
-    result = gnc_amount_edit_expr_is_valid (GNC_AMOUNT_EDIT (info->cash_edit), &amount, TRUE);
+    result = gnc_amount_edit_expr_is_valid (GNC_AMOUNT_EDIT (info->cash_edit), &amount, TRUE, NULL);
     if (result == -1)
         return TRUE; /* Optional field is empty */
     else if ( result > 0)
@@ -621,7 +630,7 @@ gnc_stock_split_assistant_create (StockSplitInfo *info)
         info->distribution_edit = amount;
 
         label = GTK_WIDGET(gtk_builder_get_object(builder, "distribution_label"));
-        gtk_label_set_mnemonic_widget(GTK_LABEL(label), amount);
+        gnc_amount_edit_make_mnemonic_target (GNC_AMOUNT_EDIT(amount), label);
 
         amount = gnc_amount_edit_new ();
         gnc_amount_edit_set_print_info (GNC_AMOUNT_EDIT (amount),
@@ -634,12 +643,14 @@ gnc_stock_split_assistant_create (StockSplitInfo *info)
         info->price_edit = amount;
 
         label = GTK_WIDGET(gtk_builder_get_object(builder, "price_label"));
-        gtk_label_set_mnemonic_widget(GTK_LABEL(label), amount);
+        gnc_amount_edit_make_mnemonic_target (GNC_AMOUNT_EDIT(amount), label);
 
         info->price_currency_edit = gnc_currency_edit_new();
         gnc_currency_edit_set_currency (GNC_CURRENCY_EDIT(info->price_currency_edit), gnc_default_currency());
         gtk_widget_show (info->price_currency_edit);
         gtk_grid_attach (GTK_GRID(table), info->price_currency_edit, 1, 6, 1, 1);
+        g_signal_connect (info->price_currency_edit, "changed",
+                          G_CALLBACK (gnc_stock_split_details_valid_cb), info);
     }
 
     /* Cash page Widgets */
@@ -778,6 +789,7 @@ gnc_stock_split_dialog (GtkWidget *parent, Account * initial)
         return;
     }
 
+    gtk_window_set_transient_for (GTK_WINDOW (info->window), GTK_WINDOW(parent));
     gtk_widget_show_all (info->window);
 
     gnc_window_adjust_for_screen (GTK_WINDOW(info->window));
