@@ -113,7 +113,8 @@ gnc_entry_ledger_get_account_by_name (GncEntryLedger *ledger, BasicCell * bcell,
         else
             account_types = g_list_prepend (account_types, (gpointer)ACCT_TYPE_EXPENSE);
 
-        account = gnc_ui_new_accounts_from_name_window_with_types (GTK_WINDOW (ledger->parent), name, account_types);
+        account = gnc_ui_new_accounts_from_name_with_defaults (GTK_WINDOW (ledger->parent), name, account_types,
+                                                               NULL, NULL);
         g_list_free ( account_types );
         if (!account)
             return NULL;
@@ -720,11 +721,16 @@ gnc_entry_ledger_compute_value (GncEntryLedger *ledger,
     disc_type = gnc_entry_ledger_get_type (ledger, ENTRY_DISTYPE_CELL);
     disc_how = gnc_entry_ledger_get_type (ledger, ENTRY_DISHOW_CELL);
 
-    /* Bills and exp-vouchers don't have discounts */
+    /* Some ledger types (see full list in gnc_entry_ledger_set_cells)
+       don't have discounts */
     if (ledger->type == GNCENTRY_BILL_ENTRY ||
-            ledger->type == GNCENTRY_BILL_VIEWER ||
-            ledger->type == GNCENTRY_EXPVOUCHER_ENTRY ||
-            ledger->type == GNCENTRY_EXPVOUCHER_VIEWER)
+        ledger->type == GNCENTRY_BILL_VIEWER ||
+        ledger->type == GNCENTRY_VEND_CREDIT_NOTE_ENTRY ||
+        ledger->type == GNCENTRY_VEND_CREDIT_NOTE_VIEWER ||
+        ledger->type == GNCENTRY_EXPVOUCHER_ENTRY ||
+        ledger->type == GNCENTRY_EXPVOUCHER_VIEWER ||
+        ledger->type == GNCENTRY_EMPL_CREDIT_NOTE_ENTRY ||
+        ledger->type == GNCENTRY_EMPL_CREDIT_NOTE_VIEWER)
     {
         g_assert (gnc_numeric_zero_p (discount));
         disc_type = GNC_AMT_TYPE_VALUE;
