@@ -2,7 +2,7 @@
 ;; average-balance.scm
 ;; Report history of account balance and other info
 ;;
-;; Author makes no implicit or explicit guarantee of accuracy of 
+;; Author makes no implicit or explicit guarantee of accuracy of
 ;;  these calculations and accepts no responsibility for direct
 ;;  or indirect losses incurred as a result of using this software.
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -52,102 +52,89 @@
   ;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (options-generator)
-  (let* ((options (gnc:new-options))
-         ;; register a configuration option for the report
-         (register-option
-          (lambda (new-option)
-            (gnc:register-option options new-option))))      
+  (let ((options (gnc-new-optiondb)))
 
     ;; General tab
     (gnc:options-add-date-interval!
      options gnc:pagename-general optname-from-date optname-to-date "a")
 
-    (gnc:options-add-interval-choice! 
+    (gnc:options-add-interval-choice!
      options gnc:pagename-general optname-stepsize "b" 'MonthDelta)
 
     ;; Report's currency
-    (gnc:options-add-currency! 
+    (gnc:options-add-currency!
      options gnc:pagename-general optname-report-currency "c")
-    
-    (gnc:options-add-price-source! 
+
+    (gnc:options-add-price-source!
      options gnc:pagename-general
      optname-price-source "d" 'weighted-average)
 
     ;; Account tab
-    (register-option
-     (gnc:make-simple-boolean-option
+    (gnc-register-simple-boolean-option options
       gnc:pagename-accounts optname-subacct
-      "a" (N_ "Include sub-accounts of all selected accounts.") #t))
+      "a" (N_ "Include sub-accounts of all selected accounts.") #t)
 
-    (register-option
-     (gnc:make-simple-boolean-option
+    (gnc-register-simple-boolean-option options
       gnc:pagename-accounts optname-internal
       "b"
       (N_ "Exclude transactions that only involve two accounts, both of which are selected below. This only affects the profit and loss columns of the table.")
-      #f))
+      #f)
 
     ;; account(s) to do report on
-    (register-option
-     (gnc:make-account-list-option
+    (gnc-register-account-list-option options
       gnc:pagename-accounts (N_ "Accounts")
       "c" (N_ "Do transaction report on this account.")
-      (lambda ()
-        ;; FIXME : gnc:get-current-accounts disappeared
-        (let ((current-accounts '()))
-          ;; If some accounts were selected, use those
-          (cond ((not (null? current-accounts)) 
-                 current-accounts)
-                (else
-                 ;; otherwise get some accounts -- here as an
-                 ;; example we get the asset and liability stuff
-                 (gnc:filter-accountlist-type
-                  (list ACCT-TYPE-BANK ACCT-TYPE-CASH ACCT-TYPE-CREDIT
-                        ACCT-TYPE-ASSET ACCT-TYPE-LIABILITY
-                        ACCT-TYPE-PAYABLE ACCT-TYPE-RECEIVABLE)
-                  ;; or: (list ACCT-TYPE-BANK ACCT-TYPE-CASH
-                  ;; ACCT-TYPE-CHECKING ACCT-TYPE-SAVINGS ACCT-TYPE-STOCK
-                  ;; ACCT-TYPE-MUTUAL ACCT-TYPE-MONEYMRKT)
-                  (gnc-account-get-children-sorted (gnc-get-current-root-account)))))))
-      #f #t))
+      (let ((current-accounts '()))
+        ;; If some accounts were selected, use those
+        (cond ((not (null? current-accounts))
+               current-accounts)
+              (else
+               ;; otherwise get some accounts -- here as an
+               ;; example we get the asset and liability stuff
+               (gnc-account-list-from-types (gnc-get-current-book)
+                (list ACCT-TYPE-BANK ACCT-TYPE-CASH ACCT-TYPE-CREDIT
+                      ACCT-TYPE-ASSET ACCT-TYPE-LIABILITY
+                      ACCT-TYPE-PAYABLE ACCT-TYPE-RECEIVABLE)
+                ;; or: (list ACCT-TYPE-BANK ACCT-TYPE-CASH
+                ;; ACCT-TYPE-CHECKING ACCT-TYPE-SAVINGS ACCT-TYPE-STOCK
+                ;; ACCT-TYPE-MUTUAL ACCT-TYPE-MONEYMRKT)
+                )))))
 
     ;; Display tab
-    (register-option
-     (gnc:make-simple-boolean-option
+     (gnc-register-simple-boolean-option options
       gnc:pagename-display (N_ "Show table")
-      "a" (N_ "Display a table of the selected data.") #f))
+      "a" (N_ "Display a table of the selected data.") #f)
 
-    (register-option
-     (gnc:make-simple-boolean-option
+     (gnc-register-simple-boolean-option options
       gnc:pagename-display (N_ "Show plot")
-      "b" (N_ "Display a graph of the selected data.") #t))
+      "b" (N_ "Display a graph of the selected data.") #t)
 
-    (register-option
-     (gnc:make-list-option
+     (gnc-register-list-option options
       gnc:pagename-display (N_ "Plot Type")
-      "c" (N_ "The type of graph to generate.") (list 'AvgBalPlot)
-      (list 
+      "c" (N_ "The type of graph to generate.") "AvgBalPlot"
+      (list
        (vector 'AvgBalPlot (N_ "Average"))
        (vector 'GainPlot (N_ "Profit"))
-       (vector 'GLPlot (N_ "Gain/Loss")))))
+       (vector 'GLPlot (N_ "Gain/Loss"))))
 
-    (gnc:options-add-plot-size! 
-     options gnc:pagename-display 
+    (gnc:options-add-plot-size!
+     options gnc:pagename-display
      optname-plot-width optname-plot-height "d" (cons 'percent 100.0) (cons 'percent 100.0))
 
     ;; Set the general page as default option tab
-    (gnc:options-set-default-section options gnc:pagename-general)      
-    
+    (GncOptionDBPtr-set-default-section options gnc:pagename-general)
+
     options))
 
   ;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Some utilities for generating the data 
+;; Some utilities for generating the data
   ;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define columns
   ;; Watch out -- these names should be consistent with the display
   ;; option where you choose them, otherwise users are confused.
-  (list (G_ "Period start") (G_ "Period end") (G_ "Average") 
-        (G_ "Maximum") (G_ "Minimum") (G_ "Gain") 
+  (list (G_ "Period start") (G_ "Period end") (G_ "Average")
+        (G_ "Maximum") (G_ "Minimum") (G_ "Gain")
         (G_ "Loss") (G_ "Profit") ))
 
 
@@ -273,21 +260,20 @@
 (define (renderer report-obj)
 
   (define (get-option section name)
-    (gnc:option-value 
-     (gnc:lookup-option (gnc:report-options report-obj) section name)))
+    (gnc-optiondb-lookup-value (gnc:report-options report-obj) section name))
 
   (gnc:report-starting reportname)
-  (let* ((report-title (get-option gnc:pagename-general 
+  (let* ((report-title (get-option gnc:pagename-general
                                    gnc:optname-reportname))
          (begindate (gnc:time64-start-day-time
-                     (gnc:date-option-absolute-time 
+                     (gnc:date-option-absolute-time
                       (get-option gnc:pagename-general optname-from-date))))
-         (enddate (gnc:time64-end-day-time 
-                   (gnc:date-option-absolute-time 
+         (enddate (gnc:time64-end-day-time
+                   (gnc:date-option-absolute-time
                     (get-option gnc:pagename-general optname-to-date))))
          (stepsize (gnc:deltasym-to-delta
                     (get-option gnc:pagename-general optname-stepsize)))
-         (report-currency (get-option gnc:pagename-general 
+         (report-currency (get-option gnc:pagename-general
                                       optname-report-currency))
          (price-source (get-option gnc:pagename-general
                                    optname-price-source))
@@ -304,8 +290,8 @@
 
          (document   (gnc:make-html-document))
 
-	 (commodity-list #f)
-	 (exchange-fn #f)
+         (commodity-list #f)
+         (exchange-fn #f)
          (all-zeros? #t))
 
     ;;(warn commodity-list)
@@ -321,40 +307,40 @@
           ;; routine needs to send progress reports, or the price
           ;; lookup should be distributed and done when actually
           ;; needed so as to amortize the cpu time properly.
-	  (gnc:report-percent-done 1)
-	  (set! commodity-list (gnc:accounts-get-commodities
+          (gnc:report-percent-done 1)
+          (set! commodity-list (gnc:accounts-get-commodities
                                 accounts report-currency))
 
-	  (gnc:report-percent-done 5)
-	  (set! exchange-fn (gnc:case-exchange-time-fn 
-                             price-source report-currency 
+          (gnc:report-percent-done 5)
+          (set! exchange-fn (gnc:case-exchange-time-fn
+                             price-source report-currency
                              commodity-list enddate
-			     5 20))
-	  (gnc:report-percent-done 20)
+                             5 20))
+          (gnc:report-percent-done 20)
 
-          ;; initialize the query to find splits in the right 
+          ;; initialize the query to find splits in the right
           ;; date range and accounts
           (qof-query-set-book query (gnc-get-current-book))
 
-	  ;; for balance purposes, we don't need to do this, but it cleans up
-	  ;; the table display.
+          ;; for balance purposes, we don't need to do this, but it cleans up
+          ;; the table display.
           (xaccQueryAddClearedMatch
            query (logand CLEARED-ALL (lognot CLEARED-VOIDED)) QOF-QUERY-AND)
-          ;; add accounts to the query (include subaccounts 
+          ;; add accounts to the query (include subaccounts
           ;; if requested)
-	  (gnc:report-percent-done 25)
+          (gnc:report-percent-done 25)
 
           (xaccQueryAddAccountMatch query accounts QOF-GUID-MATCH-ANY QOF-QUERY-AND)
-          
-          ;; match splits between start and end dates 
+
+          ;; match splits between start and end dates
           (xaccQueryAddDateMatchTT
            query #t begindate #t enddate QOF-QUERY-AND)
           (qof-query-set-sort-order query
-				    (list SPLIT-TRANS TRANS-DATE-POSTED)
-				    (list QUERY-DEFAULT-SORT)
-				    '())
-          
-	  (gnc:report-percent-done 40)
+                                    (list SPLIT-TRANS TRANS-DATE-POSTED)
+                                    (list QUERY-DEFAULT-SORT)
+                                    '())
+
+          (gnc:report-percent-done 40)
 
           (let* ((splits (qof-query-run query))
                  (daily-dates (gnc:make-date-list begindate enddate DayDelta))
@@ -394,9 +380,9 @@
                                 internal-included exchange-fn report-currency))))
 
           (gnc:report-percent-done 70)
-          
-          ;; make a plot (optionally)... if both plot and table, 
-          ;; plot comes first. 
+
+          ;; make a plot (optionally)... if both plot and table,
+          ;; plot comes first.
           (if show-plot?
               (let ((barchart (gnc:make-html-chart))
                     (height (get-option gnc:pagename-display optname-plot-height))
@@ -405,7 +391,7 @@
                 (if (memq 'AvgBalPlot plot-type)
                     (let
                         ((number-data
-                          (map 
+                          (map
                            (lambda (row) (list-ref row 2)) data)))
                       (if (not (every zero? number-data))
                           (begin
@@ -416,7 +402,7 @@
                             (set! all-zeros? #f)))))
 
                 (if (memq 'GainPlot plot-type)
-                    (let ((number-data 
+                    (let ((number-data
                            (map (lambda (row) (list-ref row 7)) data)))
                       (if (not (every zero? number-data))
                           (begin
@@ -427,11 +413,11 @@
                             (set! all-zeros? #f)))))
 
                 (if (memq 'GLPlot plot-type)
-                    (let ((debit-data 
+                    (let ((debit-data
                            (map (lambda (row) (list-ref row 5)) data))
                           (credit-data
                            (map (lambda (row) (list-ref row 6)) data)))
-                      ;; debit column 
+                      ;; debit column
                       (if (not (and
                                 (every zero? debit-data)
                                 (every zero? credit-data)))
@@ -445,7 +431,7 @@
                                                              credit-data
                                                              "#FF4136")
                             (set! all-zeros? #f)))))
-                
+
                 (if (not all-zeros?)
                     (begin
                       (gnc:html-chart-set-currency-iso!
@@ -455,19 +441,18 @@
 
                       (gnc:html-chart-set-data-labels! barchart col-labels)
                       (gnc:html-chart-set-data-labels! barchart (map car data))
-                      ;; (gnc:html-chart-set-row-labels-rotated?! barchart #t)
                       (gnc:html-chart-set-width! barchart width)
                       (gnc:html-chart-set-height! barchart height)
                       (gnc:html-chart-set-height! barchart height)
                       (gnc:html-document-add-object! document barchart))
                     (gnc:html-document-add-object!
                      document
-                     (gnc:html-make-empty-data-warning 
+                     (gnc:html-make-empty-data-warning
                       report-title (gnc:report-id report-obj))))))
-          
+
           ;; make a table (optionally)
-	  (gnc:report-percent-done 80)
-          (if show-table? 
+          (gnc:report-percent-done 80)
+          (if show-table?
               (let ((table (gnc:make-html-table))
                     (scu (gnc-commodity-get-fraction report-currency)))
                 (gnc:html-table-set-col-headers!
@@ -493,10 +478,10 @@
                 (gnc:html-document-add-object! document table))))
 
         ;; if there are no accounts selected...
-        (gnc:html-document-add-object! 
+        (gnc:html-document-add-object!
          document
-         (gnc:html-make-no-account-warning 
-	  report-title (gnc:report-id report-obj))))
+         (gnc:html-make-no-account-warning
+          report-title (gnc:report-id report-obj))))
     (gnc:report-finished)
     document))
 
