@@ -50,38 +50,15 @@
 #ifndef GNC_GSETTINGS_H
 #define GNC_GSETTINGS_H
 
-#include <gio/gio.h>
+#include <glib.h>
 
-#define GSET_SCHEMA_PREFIX            "org.gnucash"
-
-/** Convert a partial schema name into a complete gsettings schema name.
- *
- *  This function takes a partial gsettings schema name and converts
- *  it into a fully qualified gsettings schema name.  It does this
- *  by prepending the standard prefix for all gnucash schemas.
- *  If the schema is already fully qualified (i.e. begins with the
- *  default schema prefix, this routine will not change it.
- *
- *  @param name A partial schema name.  The default prefix is
- *  prepended to this name to produce a fully qualified schema
- *  name.
- *
- *  @return This function returns a string pointer to the fully
- *  qualified schema name.  It is the caller's responsibility to
- *  free this string.
- */
-gchar *gnc_gsettings_normalize_schema_name (const gchar *name);
-
-
-/** Set the default gsettings schema prefix. This is
- *  used to generate complete schema id's if only
- *  partial id's are passed.
- */
-void gnc_gsettings_set_prefix (const gchar *prefix);
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /** Get the default gsettings schema prefix.
  *  If none was set explicitly, this defaults to
- *  "org.gnucash"
+ *  "org.gnucash.GnuCash"
  */
 const gchar *gnc_gsettings_get_prefix (void);
 
@@ -283,8 +260,7 @@ gboolean gnc_gsettings_get_bool (const gchar *schema,
  *  processing, this function passed on the value of zero as returned
  *  by GSettings.
  */
-gint gnc_gsettings_get_int (const gchar *schema,
-                            const gchar *key);
+gint gnc_gsettings_get_int (const gchar *schema, const gchar *key);
 
 /** Get an float value from GSettings.
  *
@@ -309,8 +285,7 @@ gint gnc_gsettings_get_int (const gchar *schema,
  *  processing, this function passed on the value of zero as returned
  *  by GSettings.
  */
-gdouble gnc_gsettings_get_float (const gchar *schema,
-                                 const gchar *key);
+gdouble gnc_gsettings_get_float (const gchar *schema, const gchar *key);
 
 /** Get a string value from GSettings.
  *
@@ -336,8 +311,7 @@ gdouble gnc_gsettings_get_float (const gchar *schema,
  *  GSettings.  It is the callers responsibility to free any string
  *  returned by this function.
  */
-gchar *gnc_gsettings_get_string (const gchar *schema,
-                                 const gchar *key);
+gchar *gnc_gsettings_get_string (const gchar *schema, const gchar *key);
 
 /** Get an enum value from GSettings.
  *
@@ -362,8 +336,7 @@ gchar *gnc_gsettings_get_string (const gchar *schema,
  *  processing, this function passed on the value of zero as returned
  *  by GSettings.
  */
-gint gnc_gsettings_get_enum (const gchar *schema,
-                             const gchar *key);
+gint gnc_gsettings_get_enum (const gchar *schema, const gchar *key);
 
 /** Get an arbitrary combination of values from GSettings.
  *
@@ -392,8 +365,7 @@ gint gnc_gsettings_get_enum (const gchar *schema,
  *  It is the callers responsibility to free any GVariant data returned
  *  by this function.
  */
-GVariant *gnc_gsettings_get_value (const gchar *schema,
-                                   const gchar *key);
+GVariant *gnc_gsettings_get_value (const gchar *schema, const gchar *key);
 
 /** @} */
 
@@ -423,8 +395,7 @@ GVariant *gnc_gsettings_get_value (const gchar *schema,
  *  @return This function returns true if the value was set successfully
  *  on the key or false if not.
  */
-gboolean gnc_gsettings_set_bool (const gchar *schema,
-                                 const gchar *key,
+gboolean gnc_gsettings_set_bool (const gchar *schema, const gchar *key,
                                  gboolean value);
 
 /** Store an integer value into GSettings.
@@ -448,8 +419,7 @@ gboolean gnc_gsettings_set_bool (const gchar *schema,
  *  @return This function returns true if the value was set successfully
  *  on the key or false if not.
  */
-gboolean gnc_gsettings_set_int (const gchar *schema,
-                                const gchar *key,
+gboolean gnc_gsettings_set_int (const gchar *schema, const gchar *key,
                                 gint value);
 
 /** Store a float value into GSettings.
@@ -473,8 +443,7 @@ gboolean gnc_gsettings_set_int (const gchar *schema,
  *  @return This function returns true if the value was set successfully
  *  on the key or false if not.
  */
-gboolean gnc_gsettings_set_float (const gchar *schema,
-                                  const gchar *key,
+gboolean gnc_gsettings_set_float (const gchar *schema, const gchar *key,
                                   gdouble value);
 
 
@@ -501,8 +470,7 @@ gboolean gnc_gsettings_set_float (const gchar *schema,
  *  @return This function returns true if the value was set successfully
  *  on the key or false if not.
  */
-gboolean gnc_gsettings_set_string (const gchar *schema,
-                                   const gchar *key,
+gboolean gnc_gsettings_set_string (const gchar *schema, const gchar *key,
                                    const gchar *value);
 
 /** Store an enum value into GSettings.
@@ -526,8 +494,7 @@ gboolean gnc_gsettings_set_string (const gchar *schema,
  *  @return This function returns true if the value was set successfully
  *  on the key or false if not.
  */
-gboolean gnc_gsettings_set_enum (const gchar *schema,
-                                 const gchar *key,
+gboolean gnc_gsettings_set_enum (const gchar *schema, const gchar *key,
                                  gint value);
 
 /** Store an arbitrary combination of values into GSettings.
@@ -554,8 +521,7 @@ gboolean gnc_gsettings_set_enum (const gchar *schema,
  *  @return This function returns true if the value was set successfully
  *  on the key or false if not.
  */
-gboolean gnc_gsettings_set_value (const gchar *schema,
-                                  const gchar *key,
+gboolean gnc_gsettings_set_value (const gchar *schema, const gchar *key,
                                   GVariant *value);
 
 /** Reset a key to its default value in GSettings.
@@ -577,8 +543,7 @@ gboolean gnc_gsettings_set_value (const gchar *schema,
  *  @param key This string is the name of the particular key within
  *  the named schema of gsettings.
  */
-void gnc_gsettings_reset (const gchar *schema,
-                          const gchar *key);
+void gnc_gsettings_reset (const gchar *schema, const gchar *key);
 
 /** Reset all keys in a schema to their default values in GSettings.
  *
@@ -605,6 +570,10 @@ void gnc_gsettings_reset_schema (const gchar *schema);
  */
 void gnc_gsettings_load_backend (void);
 
+/** Free the GSettings resources.
+ */
+void gnc_gsettings_shutdown (void);
+
 /** Check whether we need to adjust the user settings
  * to a newer version.
  *
@@ -614,6 +583,10 @@ void gnc_gsettings_load_backend (void);
  */
 void gnc_gsettings_version_upgrade (void);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* GNC_GSETTINGS_H */
 /** @} */
 /** @} */
