@@ -271,6 +271,13 @@ typedef struct
     gnc_sql_query_info* pQueryInfo;
 } sql_backend;
 
+static void
+scrub_txn_callback (QofInstance* inst, [[maybe_unused]] void* data)
+{
+    auto trans = GNC_TRANSACTION(inst);
+    xaccTransBeginEdit(trans);
+    xaccTransCommitEdit(trans);
+}
 
 void
 GncSqlBackend::load (QofBook* book, QofBackendLoadType loadType)
@@ -336,6 +343,12 @@ GncSqlBackend::load (QofBook* book, QofBackendLoadType loadType)
                       gnc_commodity_commit_edit(comm);
                   });
     m_postload_commodities.clear();
+    /* We deferred the transaction scrub while loading because having
+     * m_loading true prevents changes from being written back to the
+     * database. Do that now.
+     */
+    auto transactions = qof_book_get_collection (book, GNC_ID_TRANS);
+    qof_collection_foreach(transactions, scrub_txn_callback, nullptr);
 
     /* Mark the session as clean -- though it should never be marked
      * dirty with this backend
