@@ -27,7 +27,7 @@
 #include <config.h>
 #include <stdlib.h>
 #include <string.h>
-#include <AccountP.h>
+#include <AccountP.hpp>
 #include <Account.h>
 
 #include "gnc-xml-helper.h"
