@@ -22,10 +22,9 @@
 
 #ifndef GNC_ADDRESS_XML_V2_H
 #define GNC_ADDRESS_XML_V2_H
-extern "C"
-{
+
 #include "gncAddress.h"
-}
+
 gboolean   gnc_dom_tree_to_address (xmlNodePtr node, GncAddress* address);
 xmlNodePtr gnc_address_to_dom_tree (const char* tag, GncAddress* addr);
 void gnc_address_xml_initialize (void);
