@@ -73,7 +73,7 @@ const gchar* invoice_version_string = "2.0.0";
 static void
 maybe_add_string (xmlNodePtr ptr, const char* tag, const char* str)
 {
-    if (str && strlen (str) > 0)
+    if (str && *str)
         xmlAddChild (ptr, text_to_dom_tree (tag, str));
 }
 
@@ -382,11 +382,8 @@ static gboolean
 invoice_tochargeamt_handler (xmlNodePtr node, gpointer invoice_pdata)
 {
     struct invoice_pdata* pdata = static_cast<decltype (pdata)> (invoice_pdata);
-    gnc_numeric* num = dom_tree_to_gnc_numeric (node);
-    g_return_val_if_fail (num, FALSE);
 
-    gncInvoiceSetToChargeAmount (pdata->invoice, *num);
-    g_free (num);
+    gncInvoiceSetToChargeAmount (pdata->invoice, dom_tree_to_gnc_numeric (node));
     return TRUE;
 }
 
