@@ -34,11 +34,11 @@
 
 #include <gnc-xml-helper.h>
 #include <Account.h>
-#include <AccountP.h>
+#include <AccountP.hpp>
 #include <Query.h>
 #include <Scrub.h>
 #include <Transaction.h>
-#include <TransactionP.h>
+#include <TransactionP.hpp>
 #include <TransLog.h>
 #include <gnc-pricedb.h>
 #include <gnc-pricedb-p.h>
