@@ -40,9 +40,9 @@
 #include <test-engine-stuff.h>
 #include <unittest-support.h>
 
-#include <AccountP.h>
+#include <AccountP.hpp>
 #include <Transaction.h>
-#include <TransactionP.h>
+#include <TransactionP.hpp>
 
 #include "../gnc-xml-helper.h"
 #include "../gnc-xml.h"
