@@ -29,13 +29,17 @@
 #include <memory>
 #include <string>
 #include <vector>
+#include <functional>
+#include <optional>
+
+#include <boost/date_time/gregorian/gregorian.hpp>
 
 typedef struct
 {
     int year;  //1400-9999
     int month; //1-12
     int day; //1-31
-} ymd;
+} gnc_ymd;
 
 enum class DayPart {
     start,    // 00:00 local
@@ -105,7 +109,8 @@ public:
  * default is UTC, not the local one.
  * @exception std::invalid_argument if the year is outside the constraints.
  */
-    GncDateTime(std::string str);
+    GncDateTime(const std::string& str);
+    GncDateTime(const char* str);
     ~GncDateTime();
 /** Set the GncDateTime to the date and time indicated in the computer's clock.
  */
@@ -171,6 +176,8 @@ private:
  * GncDate::c_formats class variable and work with those.
  */
 
+using StringToDate = std::function<boost::gregorian::date(const std::string&)>;
+
 class GncDateFormat
 {
 public:
@@ -181,6 +188,10 @@ public:
      */
     GncDateFormat (const char* fmt, const char* re) :
     m_fmt(fmt), m_re(re) {}
+    GncDateFormat (const char* fmt, StringToDate str_to_date, const char* re) :
+        m_fmt(fmt), m_re(re), m_str_to_date(str_to_date) {}
+    GncDateFormat (const char* fmt, StringToDate str_to_date) :
+        m_fmt(fmt), m_str_to_date(str_to_date) {}
     /** A string representing the format. */
     const std::string m_fmt;
 private:
@@ -188,6 +199,7 @@ private:
      * only be used internally by the gnc-datetime code.
      */
     const std::string m_re;
+    std::optional<StringToDate> m_str_to_date;
 
     friend class GncDateImpl;
 };
@@ -272,10 +284,10 @@ class GncDate
         GncDate& operator=(GncDate&&);
         /** Set the date object to the computer clock's current day. */
         void today();
-        /** Get the year, month, and day from the date as a ymd.
-         *  @return ymd struct
+        /** Get the year, month, and day from the date as a gnc_ymd.
+         *  @return gnc_ymd struct
          */
-        ymd year_month_day() const;
+        gnc_ymd year_month_day() const;
         /** Format the GncDate into a std::string
          *  @param format A cstr describing the way the date and time are
          *  presented. Code letters preceded with % stand in for arguments;
