@@ -21,10 +21,7 @@
  * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
  *******************************************************************/
-extern "C"
-{
 #include <config.h>
-}
 
 #include "gnc-int128.hpp"
 
@@ -700,7 +697,6 @@ div_single_leg (uint64_t* u, size_t m, uint64_t v,
                 GncInt128& q, GncInt128& r) noexcept
 {
     uint64_t qv[sublegs] {};
-    uint64_t carry {};
     bool negative {q.isNeg()};
     bool rnegative {r.isNeg()};
     for (int i = m - 1; i >= 0; --i)
@@ -899,7 +895,7 @@ decimal_from_binary (uint64_t d[dec_array_size], uint64_t hi, uint64_t lo)
     d[0] = lo & bin_mask;
     d[1] = (lo >> 32) & bin_mask;
     d[2] = hi & bin_mask;
-    d[3] = (hi >> 32) & bin_mask, 0;
+    d[3] = (hi >> 32) & bin_mask;
 
     d[0] += coeff_3[3] * d[3] + coeff_2[3] * d[2] + coeff_1[3] * d[1];
     uint64_t q {d[0] / dec_div};
@@ -919,21 +915,21 @@ decimal_from_binary (uint64_t d[dec_array_size], uint64_t hi, uint64_t lo)
 static const uint8_t char_buf_size {41}; //39 digits plus sign and trailing null
 
 char*
-GncInt128::asCharBufR(char* buf) const noexcept
+GncInt128::asCharBufR(char* buf, uint32_t size) const noexcept
 {
     if (isOverflow())
     {
-        sprintf (buf, "%s", "Overflow");
+        snprintf (buf, size, "%s", "Overflow");
         return buf;
     }
     if (isNan())
     {
-        sprintf (buf, "%s", "NaN");
+        snprintf (buf, size, "%s", "NaN");
         return buf;
     }
     if (isZero())
     {
-        sprintf (buf, "%d", 0);
+        snprintf (buf, size, "%d", 0);
         return buf;
     }
     uint64_t d[dec_array_size] {};
@@ -946,10 +942,11 @@ GncInt128::asCharBufR(char* buf) const noexcept
     for (unsigned int i {dec_array_size}; i; --i)
         if (d[i - 1] || trailing)
         {
+            uint32_t new_size = size - (next - buf);
             if (trailing)
-                next += sprintf (next, "%8.8" PRIu64, d[i - 1]);
+                next += snprintf (next, new_size, "%8.8" PRIu64, d[i - 1]);
             else
-                next += sprintf (next, "%" PRIu64, d[i - 1]);
+                next += snprintf (next, new_size, "%" PRIu64, d[i - 1]);
 
             trailing = true;
         }
@@ -961,7 +958,7 @@ std::ostream&
 operator<< (std::ostream& stream, const GncInt128& a) noexcept
 {
     char buf[char_buf_size] {};
-    stream << a.asCharBufR (buf);
+    stream << a.asCharBufR (buf, char_buf_size - 1);
     return stream;
 }
 
