@@ -26,15 +26,12 @@
  */
 #include <glib.h>
 
-extern "C"
-{
 #include <config.h>
 #include <unistd.h>
 #include "qof.h"
 #include "Account.h"
 #include "cashobjects.h"
 #include "test-engine-stuff.h"
-}
 #include <qofinstance-p.h>
 #include "test-stuff.h"
 
@@ -83,8 +80,7 @@ run_test (void)
 
     /*****/
 
-    qof_session_end (sess);
-
+    qof_session_destroy (sess);
 }
 
 int
