@@ -60,8 +60,8 @@ public:
     void sync(QofBook* book) override {}
     void safe_sync(QofBook* book) override {}
     void begin(QofInstance* inst) override {
-        g_assert(inst);
-        g_assert(QOF_IS_INSTANCE(inst));
+        g_assert_true(inst);
+        g_assert_true(QOF_IS_INSTANCE(inst));
         commit_test.m_inst = inst;
     }
     void set_error(QofBackendError err) {
@@ -69,10 +69,10 @@ public:
         commit_test.m_err = err;
     }
     void commit(QofInstance* inst) override {
-        g_assert( inst );
-        g_assert( QOF_IS_INSTANCE( inst ) );
-        g_assert( commit_test.m_inst == inst );
-        g_assert( commit_test.m_be == this );
+        g_assert_true( inst );
+        g_assert_true( QOF_IS_INSTANCE( inst ) );
+        g_assert_true( commit_test.m_inst == inst );
+        g_assert_true( commit_test.m_be == this );
         commit_test.m_commit_called = true;
         if (qof_instance_is_dirty(inst))
             qof_instance_mark_clean(inst);
@@ -95,23 +95,23 @@ typedef struct
 
 static void
 on_error(QofInstance* inst, QofBackendError err) {
-    g_assert( inst );
-    g_assert( QOF_IS_INSTANCE( inst ) );
-    g_assert( commit_test.m_err == err );
+    g_assert_true( inst );
+    g_assert_true( QOF_IS_INSTANCE( inst ) );
+    g_assert_true( commit_test.m_err == err );
     commit_test.m_on_error_called = true;
 }
 static void
 on_done(QofInstance* inst) {
-    g_assert( inst );
-    g_assert( QOF_IS_INSTANCE( inst ) );
-    g_assert( commit_test.m_inst == inst );
+    g_assert_true( inst );
+    g_assert_true( QOF_IS_INSTANCE( inst ) );
+    g_assert_true( commit_test.m_inst == inst );
     commit_test.m_on_done_called = true;
 }
 static void
 on_free(QofInstance* inst) {
-    g_assert( inst );
-    g_assert( QOF_IS_INSTANCE( inst ) );
-    g_assert(commit_test.m_inst == inst );
+    g_assert_true( inst );
+    g_assert_true( QOF_IS_INSTANCE( inst ) );
+    g_assert_true(commit_test.m_inst == inst );
     commit_test.m_on_free_called = true;
 }
 
@@ -146,14 +146,14 @@ test_instance_set_get_book( Fixture *fixture, gconstpointer pData )
     /* set up */
     book = qof_book_new();
 
-    g_assert( QOF_IS_INSTANCE( fixture->inst ) );
+    g_assert_true( QOF_IS_INSTANCE( fixture->inst ) );
 
     g_test_message( "Setting and getting book" );
     qof_instance_set_book( fixture->inst, book );
-    g_assert( book == qof_instance_get_book( fixture->inst ) );
+    g_assert_true( book == qof_instance_get_book( fixture->inst ) );
 
     g_test_message( "Getting book when instance is null" );
-    g_assert( qof_instance_get_book( NULL ) == NULL );
+    g_assert_true( qof_instance_get_book( NULL ) == NULL );
 
     /* Clean up */
     qof_book_destroy( book );
@@ -167,21 +167,21 @@ test_instance_set_get_guid( Fixture *fixture, gconstpointer pData )
     /* on null instance deprecated getter returns empty guid
      * while instance_get_guid returns null
      */
-    g_assert( !qof_instance_get_guid( NULL ) );
-    g_assert( qof_entity_get_guid( NULL ) == guid_null() );
+    g_assert_true( !qof_instance_get_guid( NULL ) );
+    g_assert_true( qof_entity_get_guid( NULL ) == guid_null() );
 
     /* set up */
     gncGuid = guid_new();
-    g_assert( QOF_IS_INSTANCE( fixture->inst ) );
-    g_assert( gncGuid );
+    g_assert_true( QOF_IS_INSTANCE( fixture->inst ) );
+    g_assert_true( gncGuid );
 
     /* guid already exists after instance init */
     g_test_message( "Setting new guid" );
-    g_assert( qof_instance_get_guid( fixture->inst ) );
-    g_assert( !guid_equal( gncGuid, qof_instance_get_guid( fixture->inst ) ) );
+    g_assert_true( qof_instance_get_guid( fixture->inst ) );
+    g_assert_true( !guid_equal( gncGuid, qof_instance_get_guid( fixture->inst ) ) );
     qof_instance_set_guid( fixture->inst, gncGuid );
-    g_assert( guid_equal( gncGuid, qof_instance_get_guid( fixture->inst ) ) );
-    g_assert( guid_equal( gncGuid, qof_entity_get_guid( fixture->inst ) ) );
+    g_assert_true( guid_equal( gncGuid, qof_instance_get_guid( fixture->inst ) ) );
+    g_assert_true( guid_equal( gncGuid, qof_entity_get_guid( fixture->inst ) ) );
 
     /* Clean up */
     guid_free( gncGuid );
@@ -202,24 +202,24 @@ test_instance_new_destroy( void )
 
     g_test_message( "Testing qofinstance object initialization" );
     inst = static_cast<QofInstance*>(g_object_new(QOF_TYPE_INSTANCE, NULL));
-    g_assert( QOF_IS_INSTANCE( inst ) );
+    g_assert_true( QOF_IS_INSTANCE( inst ) );
     /* test class fields */
     klass = QOF_INSTANCE_GET_CLASS( inst );
-    g_assert( QOF_IS_INSTANCE_CLASS( klass ) );
-    g_assert( klass->get_display_name == NULL );
-    g_assert( klass->refers_to_object == NULL );
-    g_assert( klass->get_typed_referring_object_list == NULL );
+    g_assert_true( QOF_IS_INSTANCE_CLASS( klass ) );
+    g_assert_true( klass->get_display_name == NULL );
+    g_assert_true( klass->refers_to_object == NULL );
+    g_assert_true( klass->get_typed_referring_object_list == NULL );
     /* testing initial values */
-    g_assert( qof_instance_get_guid( inst ) );
-    g_assert( !qof_instance_get_collection( inst ) );
-    g_assert( qof_instance_get_book( inst ) == NULL );
-    g_assert( inst->kvp_data );
+    g_assert_true( qof_instance_get_guid( inst ) );
+    g_assert_true( !qof_instance_get_collection( inst ) );
+    g_assert_true( qof_instance_get_book( inst ) == NULL );
+    g_assert_true( inst->kvp_data );
     g_object_get( inst, "last-update", &time_priv, NULL);
     g_assert_cmpint( time_priv->t, == , 0 );
     g_assert_cmpint( qof_instance_get_editlevel( inst ), == , 0 );
-    g_assert( !qof_instance_get_destroying( inst ) );
-    g_assert( !qof_instance_get_dirty_flag( inst ) );
-    g_assert( qof_instance_get_infant( inst ) );
+    g_assert_true( !qof_instance_get_destroying( inst ) );
+    g_assert_true( !qof_instance_get_dirty_flag( inst ) );
+    g_assert_true( qof_instance_get_infant( inst ) );
     g_assert_cmpint( qof_instance_get_version( inst ), == , 0 );
     g_assert_cmpint( qof_instance_get_version_check( inst ), == , 0 );
     g_assert_cmpint( qof_instance_get_idata( inst ), == , 0 );
@@ -243,30 +243,30 @@ test_instance_init_data( void )
 
     /* set up */
     inst = static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
-    g_assert( QOF_IS_INSTANCE( inst ) );
+    g_assert_true( QOF_IS_INSTANCE( inst ) );
     book = qof_book_new();
-    g_assert( QOF_IS_BOOK( book ) );
+    g_assert_true( QOF_IS_BOOK( book ) );
     /* set fatal handler */
     g_test_log_set_fatal_handler ( ( GTestLogFatalFunc )fatal_handler, NULL );
 
     g_test_message( "Running test with correct initial data" );
     gncguid = qof_instance_get_guid( inst );
-    g_assert( gncguid );
+    g_assert_true( gncguid );
     guid_to_string_buff( gncguid, guid_id_before );
-    g_assert( qof_instance_get_book( inst ) == NULL );
-    g_assert( qof_instance_get_collection( inst ) == NULL );
+    g_assert_true( qof_instance_get_book( inst ) == NULL );
+    g_assert_true( qof_instance_get_collection( inst ) == NULL );
     /* run init */
     qof_instance_init_data( inst, test_type, book );
 
-    g_assert( qof_instance_get_book( inst ) == book );
+    g_assert_true( qof_instance_get_book( inst ) == book );
     guid_to_string_buff( gncguid, guid_id_after );
     g_assert_cmpstr( guid_id_before, != , guid_id_after );
-    g_assert( qof_instance_get_collection( inst ) != NULL );
+    g_assert_true( qof_instance_get_collection( inst ) != NULL );
     col = qof_book_get_collection( book, test_type );
-    g_assert( col );
-    g_assert( col == qof_instance_get_collection( inst ) );
+    g_assert_true( col );
+    g_assert_true( col == qof_instance_get_collection( inst ) );
     g_assert_cmpstr( inst->e_type, == , test_type );
-    g_assert( qof_collection_lookup_entity( qof_instance_get_collection( inst ), gncguid ) == inst );
+    g_assert_true( qof_collection_lookup_entity( qof_instance_get_collection( inst ), gncguid ) == inst );
 
     /* clean up */
     g_object_unref( inst );
@@ -279,26 +279,26 @@ test_instance_get_set_slots( Fixture *fixture, gconstpointer pData )
     KvpFrame *kvp_frame, *kvp_frame2;
 
     /* set up */
-    g_assert( fixture->inst );
+    g_assert_true( fixture->inst );
     kvp_frame = qof_instance_get_slots( fixture->inst );
-    g_assert( kvp_frame );
+    g_assert_true( kvp_frame );
 
     g_test_message( "Test when kvp frame is the same" );
     qof_instance_set_slots( fixture->inst, kvp_frame );
-    g_assert( kvp_frame == qof_instance_get_slots( fixture->inst ) );
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( kvp_frame == qof_instance_get_slots( fixture->inst ) );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) );
 
     g_test_message( "Test when kvp frame is not the same" );
     kvp_frame2 = new KvpFrame;
-    g_assert( kvp_frame != kvp_frame2 );
+    g_assert_true( kvp_frame != kvp_frame2 );
     qof_instance_set_slots( fixture->inst, kvp_frame2 );
-    g_assert( kvp_frame2 == qof_instance_get_slots( fixture->inst ) );
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( kvp_frame2 == qof_instance_get_slots( fixture->inst ) );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) );
 
     g_test_message( "Test when kvp frame is null" );
     qof_instance_set_slots( fixture->inst, NULL );
-    g_assert( NULL == qof_instance_get_slots( fixture->inst ) );
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( NULL == qof_instance_get_slots( fixture->inst ) );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) );
 
 }
 
@@ -361,19 +361,19 @@ test_instance_get_set_dirty( Fixture *fixture, gconstpointer pData )
     /* setup */
     col = qof_collection_new ( type );
     qof_instance_set_collection( fixture->inst, col );
-    g_assert( qof_instance_get_collection( fixture->inst ) );
+    g_assert_true( qof_instance_get_collection( fixture->inst ) );
 
     g_test_message( "Test get_dirty on empty instance returns false" );
-    g_assert( qof_instance_get_dirty( NULL ) == FALSE );
+    g_assert_true( qof_instance_get_dirty( NULL ) == FALSE );
 
     g_test_message( "Test dirty" );
-    g_assert( !qof_instance_get_dirty_flag( fixture->inst ) );
-    g_assert( !qof_collection_is_dirty( col ) );
-    g_assert( !qof_instance_get_dirty( fixture->inst ) );
+    g_assert_true( !qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( !qof_collection_is_dirty( col ) );
+    g_assert_true( !qof_instance_get_dirty( fixture->inst ) );
     qof_instance_set_dirty( fixture->inst );
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) );
-    g_assert( !qof_collection_is_dirty( col ) );
-    g_assert( qof_instance_get_dirty( fixture->inst ) );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( !qof_collection_is_dirty( col ) );
+    g_assert_true( qof_instance_get_dirty( fixture->inst ) );
 
     /* clean up */
     qof_instance_set_collection( fixture->inst, NULL );
@@ -386,8 +386,8 @@ mock_get_display_name(const QofInstance* inst)
 {
     gchar *display_name;
 
-    g_assert( inst );
-    g_assert( QOF_INSTANCE_GET_CLASS( inst )->get_display_name == mock_get_display_name );
+    g_assert_true( inst );
+    g_assert_true( QOF_INSTANCE_GET_CLASS( inst )->get_display_name == mock_get_display_name );
     is_called = TRUE;
     display_name = g_strdup_printf("Mock display name %p", inst );
     return display_name;
@@ -401,26 +401,26 @@ test_instance_display_name( Fixture *fixture, gconstpointer pData )
     gchar *display_name, *default_display_name, *mock_display_name;
 
     /* setup */
-    g_assert( fixture->inst );
+    g_assert_true( fixture->inst );
     is_called = FALSE;
     col = qof_collection_new ( type );
-    g_assert( col );
+    g_assert_true( col );
     qof_instance_set_collection( fixture->inst, col );
-    g_assert( qof_instance_get_collection( fixture->inst ) );
+    g_assert_true( qof_instance_get_collection( fixture->inst ) );
     default_display_name = g_strdup_printf( "Object %s %p", type, fixture->inst );
     mock_display_name = g_strdup_printf( "Mock display name %p", fixture->inst );
 
     g_test_message( "Test instance when display name not set" );
-    g_assert( QOF_INSTANCE_GET_CLASS( fixture->inst )->get_display_name == NULL );
+    g_assert_true( QOF_INSTANCE_GET_CLASS( fixture->inst )->get_display_name == NULL );
     display_name = qof_instance_get_display_name( fixture->inst );
-    g_assert( !is_called );
+    g_assert_true( !is_called );
     g_assert_cmpstr( display_name, == , default_display_name );
     g_free( display_name );
 
     g_test_message( "Test instance when display name is set" );
     QOF_INSTANCE_GET_CLASS( fixture->inst )->get_display_name = mock_get_display_name;
     display_name = qof_instance_get_display_name( fixture->inst );
-    g_assert( is_called );
+    g_assert_true( is_called );
     g_assert_cmpstr( display_name, == , mock_display_name );
     g_free( display_name );
 
@@ -439,32 +439,32 @@ test_instance_begin_edit( Fixture *fixture, gconstpointer pData )
 
     /* setup */
     auto be = new QofInstMockBackend;
-    g_assert( be );
+    g_assert_true( be );
     book = qof_book_new();
-    g_assert( book );
-    g_assert( QOF_IS_BOOK( book ) );
+    g_assert_true( book );
+    g_assert_true( QOF_IS_BOOK( book ) );
     qof_book_set_backend( book, be );
-    g_assert( fixture->inst );
+    g_assert_true( fixture->inst );
     fixture->inst->e_type = "test type";
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) == FALSE );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) == FALSE );
     g_assert_cmpint( qof_instance_get_editlevel( fixture->inst ), == , 0 );
 
     g_test_message( "Test when instance is null" );
     result = qof_begin_edit( NULL );
-    g_assert( result == FALSE );
+    g_assert_true( result == FALSE );
 
     g_test_message( "Test when instance's editlevel is >= 1" );
     qof_instance_increase_editlevel( fixture->inst );
     result = qof_begin_edit( fixture->inst );
-    g_assert( result == FALSE );
+    g_assert_true( result == FALSE );
     g_assert_cmpint( qof_instance_get_editlevel( fixture->inst ), == , 2 );
 
     g_test_message( "Test when instance's editlevel is <= 0 and backend not set" );
     qof_instance_reset_editlevel( fixture->inst );
     result = qof_begin_edit( fixture->inst );
-    g_assert( result == TRUE );
+    g_assert_true( result == TRUE );
     g_assert_cmpint( qof_instance_get_editlevel( fixture->inst ), == , 1 );
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) == TRUE );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) == TRUE );
 
     g_test_message( "Test when instance's editlevel is <= 0 and backend is set" );
     result = FALSE;
@@ -472,9 +472,9 @@ test_instance_begin_edit( Fixture *fixture, gconstpointer pData )
     qof_instance_set_dirty_flag( fixture->inst, FALSE );
     qof_instance_set_book( fixture->inst, book );
     result = qof_begin_edit( fixture->inst );
-    g_assert( result == TRUE );
+    g_assert_true( result == TRUE );
     g_assert_cmpint( qof_instance_get_editlevel( fixture->inst ), == , 1 );
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) == FALSE );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) == FALSE );
 
     /* clean up */
     qof_book_set_backend( book, NULL );
@@ -494,7 +494,7 @@ test_instance_commit_edit( Fixture *fixture, gconstpointer pData )
 
     g_test_message( "Test when instance set to null" );
     result = qof_commit_edit( NULL );
-    g_assert( !result );
+    g_assert_true( !result );
 
     g_test_message( "Test when instance's editlevel >= 2" );
     qof_instance_increase_editlevel( fixture->inst );
@@ -502,12 +502,12 @@ test_instance_commit_edit( Fixture *fixture, gconstpointer pData )
     g_assert_cmpint( qof_instance_get_editlevel( fixture->inst ), == , 2 );
     result = qof_commit_edit( fixture->inst );
     g_assert_cmpint( qof_instance_get_editlevel( fixture->inst ), == , 1 );
-    g_assert( !result );
+    g_assert_true( !result );
 
     g_test_message( "Test when instance's editlevel = 1" );
     result = qof_commit_edit( fixture->inst );
     g_assert_cmpint( qof_instance_get_editlevel( fixture->inst ), == , 0 );
-    g_assert( result );
+    g_assert_true( result );
 
     g_test_message( "Test when instance's editlevel < 0" );
     g_test_log_set_fatal_handler ( ( GTestLogFatalFunc )fatal_handler, NULL );
@@ -534,10 +534,10 @@ test_instance_commit_edit_part2( Fixture *fixture, gconstpointer pData )
 
     /* setup */
     auto be = new QofInstMockBackend;
-    g_assert( be );
+    g_assert_true( be );
     book = qof_book_new();
-    g_assert( book );
-    g_assert( QOF_IS_BOOK( book ) );
+    g_assert_true( book );
+    g_assert_true( QOF_IS_BOOK( book ) );
     qof_book_set_backend( book, be );
 
     /* init */
@@ -552,56 +552,56 @@ test_instance_commit_edit_part2( Fixture *fixture, gconstpointer pData )
     qof_instance_set_dirty_flag( fixture->inst, TRUE );
 
     g_test_message( "Test when instance's backend not set, callbacks not set" );
-    g_assert( qof_instance_get_infant( fixture->inst ) );
-    g_assert( !qof_instance_get_destroying( fixture->inst ) );
+    g_assert_true( qof_instance_get_infant( fixture->inst ) );
+    g_assert_true( !qof_instance_get_destroying( fixture->inst ) );
     result = qof_commit_edit_part2( fixture->inst, NULL, NULL, NULL );
-    g_assert( result );
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) );
-    g_assert( qof_instance_get_infant( fixture->inst ) );
-    g_assert( !commit_test.m_commit_called );
-    g_assert( !commit_test.m_commit_with_err_called );
-    g_assert( !commit_test.m_on_error_called );
-    g_assert( !commit_test.m_on_free_called );
-    g_assert( !commit_test.m_on_done_called );
+    g_assert_true( result );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( qof_instance_get_infant( fixture->inst ) );
+    g_assert_true( !commit_test.m_commit_called );
+    g_assert_true( !commit_test.m_commit_with_err_called );
+    g_assert_true( !commit_test.m_on_error_called );
+    g_assert_true( !commit_test.m_on_free_called );
+    g_assert_true( !commit_test.m_on_done_called );
 
     g_test_message( "Test when instance's backend not set, do_free is false" );
     qof_instance_set_destroying( fixture->inst, TRUE );
     result = qof_commit_edit_part2( fixture->inst, on_error, on_done, on_free );
-    g_assert( result );
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) );
-    g_assert( qof_instance_get_infant( fixture->inst ) );
-    g_assert( !commit_test.m_commit_called );
-    g_assert( !commit_test.m_commit_with_err_called );
-    g_assert( !commit_test.m_on_error_called );
-    g_assert( commit_test.m_on_free_called );
-    g_assert( !commit_test.m_on_done_called );
+    g_assert_true( result );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( qof_instance_get_infant( fixture->inst ) );
+    g_assert_true( !commit_test.m_commit_called );
+    g_assert_true( !commit_test.m_commit_with_err_called );
+    g_assert_true( !commit_test.m_on_error_called );
+    g_assert_true( commit_test.m_on_free_called );
+    g_assert_true( !commit_test.m_on_done_called );
 
     g_test_message( "Test when instance's backend not set, do_free is false" );
     qof_instance_set_destroying( fixture->inst, FALSE );
     commit_test.m_on_free_called = false;
     result = qof_commit_edit_part2( fixture->inst, on_error, on_done, on_free );
-    g_assert( result );
-    g_assert( qof_instance_get_dirty_flag( fixture->inst ) );
-    g_assert( qof_instance_get_infant( fixture->inst ) );
-    g_assert( !commit_test.m_commit_called );
-    g_assert( !commit_test.m_commit_with_err_called );
-    g_assert( !commit_test.m_on_error_called );
-    g_assert( !commit_test.m_on_free_called );
-    g_assert( commit_test.m_on_done_called );
+    g_assert_true( result );
+    g_assert_true( qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( qof_instance_get_infant( fixture->inst ) );
+    g_assert_true( !commit_test.m_commit_called );
+    g_assert_true( !commit_test.m_commit_with_err_called );
+    g_assert_true( !commit_test.m_on_error_called );
+    g_assert_true( !commit_test.m_on_free_called );
+    g_assert_true( commit_test.m_on_done_called );
 
     g_test_message( "Test when instance's backend is set, all cb set, no error produced" );
     qof_instance_set_book( fixture->inst, book );
     qof_instance_set_destroying( fixture->inst, FALSE );
     commit_test.m_on_done_called = false;
     result = qof_commit_edit_part2( fixture->inst, on_error, on_done, on_free );
-    g_assert( result );
-    g_assert( !qof_instance_get_dirty_flag( fixture->inst ) );
-    g_assert( !qof_instance_get_infant( fixture->inst ) );
-    g_assert( commit_test.m_commit_called );
-    g_assert( !commit_test.m_commit_with_err_called );
-    g_assert( !commit_test.m_on_error_called );
-    g_assert( !commit_test.m_on_free_called );
-    g_assert( commit_test.m_on_done_called );
+    g_assert_true( result );
+    g_assert_true( !qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( !qof_instance_get_infant( fixture->inst ) );
+    g_assert_true( commit_test.m_commit_called );
+    g_assert_true( !commit_test.m_commit_with_err_called );
+    g_assert_true( !commit_test.m_on_error_called );
+    g_assert_true( !commit_test.m_on_free_called );
+    g_assert_true( commit_test.m_on_done_called );
 
     g_test_message( "Test when instance's backend is set, all cb set, error produced" );
     commit_test.m_commit_called = false;
@@ -610,13 +610,13 @@ test_instance_commit_edit_part2( Fixture *fixture, gconstpointer pData )
     qof_instance_set_dirty_flag( fixture->inst, TRUE );
     qof_instance_set_destroying( fixture->inst, TRUE );
     result = qof_commit_edit_part2( fixture->inst, on_error, on_done, on_free );
-    g_assert( !result );
-    g_assert( !qof_instance_get_dirty_flag( fixture->inst ) );
-    g_assert( !qof_instance_get_destroying( fixture->inst ) );
-    g_assert( commit_test.m_commit_called );
-    g_assert( commit_test.m_on_error_called );
-    g_assert( !commit_test.m_on_free_called );
-    g_assert( !commit_test.m_on_done_called );
+    g_assert_true( !result );
+    g_assert_true( !qof_instance_get_dirty_flag( fixture->inst ) );
+    g_assert_true( !qof_instance_get_destroying( fixture->inst ) );
+    g_assert_true( commit_test.m_commit_called );
+    g_assert_true( commit_test.m_on_error_called );
+    g_assert_true( !commit_test.m_on_free_called );
+    g_assert_true( !commit_test.m_on_done_called );
 
     /* clean up */
     qof_book_set_backend( book, NULL );
@@ -639,10 +639,10 @@ static struct
 static gboolean
 mock_refers_to_object( const QofInstance* inst, const QofInstance* ref )
 {
-    g_assert( inst );
-    g_assert( ref );
-    g_assert( refers_test_struct.inst == inst );
-    g_assert( refers_test_struct.ref == ref );
+    g_assert_true( inst );
+    g_assert_true( ref );
+    g_assert_true( refers_test_struct.inst == inst );
+    g_assert_true( refers_test_struct.ref == ref );
     refers_test_struct.refers_to_object_called = TRUE;
     return TRUE;
 }
@@ -653,21 +653,21 @@ test_instance_refers_to_object( Fixture *fixture, gconstpointer pData )
     QofInstance * ref;
 
     ref = static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
-    g_assert( fixture->inst );
-    g_assert( ref );
-    g_assert( QOF_INSTANCE_GET_CLASS( fixture->inst )->refers_to_object == NULL );
+    g_assert_true( fixture->inst );
+    g_assert_true( ref );
+    g_assert_true( QOF_INSTANCE_GET_CLASS( fixture->inst )->refers_to_object == NULL );
     refers_test_struct.refers_to_object_called = FALSE;
     refers_test_struct.inst = fixture->inst;
     refers_test_struct.ref = ref;
 
     g_test_message( "Test when refers to object not set" );
-    g_assert( !qof_instance_refers_to_object( fixture->inst, ref ) );
-    g_assert( !refers_test_struct.refers_to_object_called );
+    g_assert_true( !qof_instance_refers_to_object( fixture->inst, ref ) );
+    g_assert_true( !refers_test_struct.refers_to_object_called );
 
     g_test_message( "Test when refers to object set" );
     QOF_INSTANCE_GET_CLASS( fixture->inst )->refers_to_object = mock_refers_to_object;
-    g_assert( qof_instance_refers_to_object( fixture->inst, ref ) );
-    g_assert( refers_test_struct.refers_to_object_called );
+    g_assert_true( qof_instance_refers_to_object( fixture->inst, ref ) );
+    g_assert_true( refers_test_struct.refers_to_object_called );
 
     g_object_unref( ref );
 }
@@ -682,10 +682,10 @@ static struct
 static gboolean
 mock_refers_to_object_from_col( const QofInstance* inst, const QofInstance* ref )
 {
-    g_assert( inst );
-    g_assert( ref );
-    g_assert( g_list_find( refers_test_struct_from_col.list, inst ) );
-    g_assert( refers_test_struct_from_col.ref == ref );
+    g_assert_true( inst );
+    g_assert_true( ref );
+    g_assert_true( g_list_find( refers_test_struct_from_col.list, inst ) );
+    g_assert_true( refers_test_struct_from_col.ref == ref );
     refers_test_struct_from_col.call_count++;
     refers_test_struct.refers_to_object_called = TRUE;
     return TRUE;
@@ -706,11 +706,11 @@ test_instance_get_referring_object_list_from_collection( void )
 
     /* setup book and ref instance */
     book = qof_book_new();
-    g_assert( book );
-    g_assert( QOF_IS_BOOK( book ) );
+    g_assert_true( book );
+    g_assert_true( QOF_IS_BOOK( book ) );
     ref =  static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
-    g_assert( ref );
-    g_assert( QOF_IS_INSTANCE( ref ) );
+    g_assert_true( ref );
+    g_assert_true( QOF_IS_INSTANCE( ref ) );
     QOF_INSTANCE_GET_CLASS( ref )->refers_to_object = NULL;
     refers_test_struct_from_col.call_count = 0;
     /* init list of entities of one type,
@@ -720,7 +720,7 @@ test_instance_get_referring_object_list_from_collection( void )
     for (i = 0; i < list_length; i++ )
     {
         auto inst = static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
-        g_assert( inst );
+        g_assert_true( inst );
         qof_instance_init_data( inst, type, book );
         inst_list = g_list_append ( inst_list, inst );
         g_assert_cmpint( g_list_length( inst_list ), == , (i + 1) );
@@ -729,9 +729,9 @@ test_instance_get_referring_object_list_from_collection( void )
 
     g_test_message( "Test when refers to object not set" );
     coll = qof_book_get_collection( book, type );
-    g_assert( coll );
+    g_assert_true( coll );
     result = qof_instance_get_referring_object_list_from_collection( coll, ref );
-    g_assert( !result );
+    g_assert_true( !result );
     g_assert_cmpint( refers_test_struct_from_col.call_count, == , 0 );
 
     g_test_message( "Test when refers to object is set" );
@@ -740,9 +740,9 @@ test_instance_get_referring_object_list_from_collection( void )
     refers_test_struct_from_col.ref = ref;
     result = qof_instance_get_referring_object_list_from_collection( coll, ref );
     if ( list_length == 0 )
-        g_assert( !result );
+        g_assert_true( !result );
     else
-        g_assert( result );
+        g_assert_true( result );
     g_assert_cmpint( g_list_length( inst_list ), == , g_list_length( result ) );
     g_assert_cmpint( g_list_length( inst_list ), == , refers_test_struct_from_col.call_count );
 
@@ -767,10 +767,10 @@ mock_get_typed_referring_object_list( const QofInstance* inst, const QofInstance
 {
     GList* result = NULL;
 
-    g_assert( inst );
-    g_assert( ref );
-    g_assert( get_typed_referring_object_list_struct.inst == inst );
-    g_assert( get_typed_referring_object_list_struct.ref == ref );
+    g_assert_true( inst );
+    g_assert_true( ref );
+    g_assert_true( get_typed_referring_object_list_struct.inst == inst );
+    g_assert_true( get_typed_referring_object_list_struct.ref == ref );
     get_typed_referring_object_list_struct.get_typed_referring_object_list_called = TRUE;
     return g_list_append( result, (gpointer) inst );
 }
@@ -787,9 +787,9 @@ test_instance_get_typed_referring_object_list( void )
     inst = static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
     ref = static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
     book = qof_book_new();
-    g_assert( inst );
-    g_assert( ref );
-    g_assert( book );
+    g_assert_true( inst );
+    g_assert_true( ref );
+    g_assert_true( book );
     QOF_INSTANCE_GET_CLASS( inst )->refers_to_object = NULL;
     QOF_INSTANCE_GET_CLASS( inst )->get_typed_referring_object_list = NULL;
     qof_instance_init_data( inst, "test type", book );
@@ -801,8 +801,8 @@ test_instance_get_typed_referring_object_list( void )
      */
     g_test_message( "Test when get typed referring object list is not set" );
     result = qof_instance_get_typed_referring_object_list( inst, ref );
-    g_assert( !result );
-    g_assert( !get_typed_referring_object_list_struct.get_typed_referring_object_list_called );
+    g_assert_true( !result );
+    g_assert_true( !get_typed_referring_object_list_struct.get_typed_referring_object_list_called );
     g_list_free( result );
 
     g_test_message( "Test when get typed referring object list is set" );
@@ -810,9 +810,9 @@ test_instance_get_typed_referring_object_list( void )
     get_typed_referring_object_list_struct.inst = inst;
     get_typed_referring_object_list_struct.ref = ref;
     result = qof_instance_get_typed_referring_object_list( inst, ref );
-    g_assert( result );
+    g_assert_true( result );
     g_assert_cmpint( g_list_length( result ), == , 1 );
-    g_assert( get_typed_referring_object_list_struct.get_typed_referring_object_list_called );
+    g_assert_true( get_typed_referring_object_list_struct.get_typed_referring_object_list_called );
     g_list_free( result );
 
     /* clean */
@@ -830,8 +830,8 @@ static struct
 static gboolean
 mock_simple_refers_to_object( const QofInstance* inst, const QofInstance* ref )
 {
-    g_assert( inst );
-    g_assert( ref );
+    g_assert_true( inst );
+    g_assert_true( ref );
     if ( inst->e_type == ref->e_type )
     {
         get_referring_object_list_struct.refers_to_object_call_count++;
@@ -843,8 +843,8 @@ mock_simple_refers_to_object( const QofInstance* inst, const QofInstance* ref )
 static GList*
 mock_simple_get_typed_referring_object_list(const QofInstance* inst, const QofInstance* ref)
 {
-    g_assert( inst );
-    g_assert( ref );
+    g_assert_true( inst );
+    g_assert_true( ref );
     get_referring_object_list_struct.get_typed_referring_object_list_count++;
     return qof_instance_get_referring_object_list_from_collection(qof_instance_get_collection(inst), ref);
 }
@@ -867,12 +867,12 @@ test_instance_get_referring_object_list( void )
 
     /* setup */
     book = qof_book_new();
-    g_assert( book );
-    g_assert( QOF_IS_BOOK( book ) );
+    g_assert_true( book );
+    g_assert_true( QOF_IS_BOOK( book ) );
     ref1 = static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
-    g_assert( ref1 );
+    g_assert_true( ref1 );
     ref2 = static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
-    g_assert( ref2 );
+    g_assert_true( ref2 );
     qof_instance_init_data( ref1, type1, book );
     qof_instance_init_data( ref2, type2, book );
     QOF_INSTANCE_GET_CLASS( ref1 )->refers_to_object = NULL;
@@ -888,7 +888,7 @@ test_instance_get_referring_object_list( void )
     for (i = 0; i < col1_length; i++ )
     {
         auto inst = static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
-        g_assert( inst );
+        g_assert_true( inst );
         qof_instance_init_data( inst, type1, book );
         inst_list1 = g_list_append ( inst_list1, inst );
         g_assert_cmpint( g_list_length( inst_list1 ), == , (i + 1) );
@@ -899,7 +899,7 @@ test_instance_get_referring_object_list( void )
     for (j = 0; j < col2_length; j++ )
     {
         auto inst = static_cast<QofInstance*>(g_object_new( QOF_TYPE_INSTANCE, NULL ));
-        g_assert( inst );
+        g_assert_true( inst );
         qof_instance_init_data( inst, type2, book );
         inst_list2 = g_list_append ( inst_list2, inst );
         g_assert_cmpint( g_list_length( inst_list2 ), == , (j + 1) );
@@ -909,12 +909,12 @@ test_instance_get_referring_object_list( void )
 
     g_test_message( "Test object list returned for ref1 instance by default" );
     result = qof_instance_get_referring_object_list( ref1 );
-    g_assert( !result );
+    g_assert_true( !result );
     g_assert_cmpint( get_referring_object_list_struct.refers_to_object_call_count, == , 0 );
 
     g_test_message( "Test object list returned for ref2 instance by default" );
     result = qof_instance_get_referring_object_list( ref2 );
-    g_assert( !result );
+    g_assert_true( !result );
     g_assert_cmpint( get_referring_object_list_struct.refers_to_object_call_count, == , 0 );
 
     /*
@@ -926,7 +926,7 @@ test_instance_get_referring_object_list( void )
     g_test_message( "Test object list returned for ref1 instance when refers_to_object is set" );
     QOF_INSTANCE_GET_CLASS( ref1 )->refers_to_object = mock_simple_refers_to_object;
     result = qof_instance_get_referring_object_list( ref1 );
-    g_assert( result );
+    g_assert_true( result );
     g_assert_cmpint( g_list_length( result ), == , col1_length + 1 );
     g_assert_cmpint( get_referring_object_list_struct.refers_to_object_call_count, == , col1_length + 1 );
     g_list_free( result );
@@ -934,7 +934,7 @@ test_instance_get_referring_object_list( void )
     g_test_message( "Test object list returned for ref2 instance when refers_to_object is set" );
     get_referring_object_list_struct.refers_to_object_call_count = 0;
     result = qof_instance_get_referring_object_list( ref2 );
-    g_assert( result );
+    g_assert_true( result );
     g_assert_cmpint( g_list_length( result ), == , col2_length + 1 );
     g_assert_cmpint( get_referring_object_list_struct.refers_to_object_call_count, == , col2_length + 1 );
     g_list_free( result );
@@ -944,7 +944,7 @@ test_instance_get_referring_object_list( void )
     get_referring_object_list_struct.refers_to_object_call_count = 0;
     get_referring_object_list_struct.get_typed_referring_object_list_count = 0;
     result = qof_instance_get_referring_object_list( ref1 );
-    g_assert( result );
+    g_assert_true( result );
     g_assert_cmpint( g_list_length( result ), == , col1_length + 1 );
     g_assert_cmpint( get_referring_object_list_struct.refers_to_object_call_count, == , col1_length + 1 );
     g_assert_cmpint( get_referring_object_list_struct.get_typed_referring_object_list_count, == , 2 );
@@ -954,7 +954,7 @@ test_instance_get_referring_object_list( void )
     get_referring_object_list_struct.refers_to_object_call_count = 0;
     get_referring_object_list_struct.get_typed_referring_object_list_count = 0;
     result = qof_instance_get_referring_object_list( ref2 );
-    g_assert( result );
+    g_assert_true( result );
     g_assert_cmpint( g_list_length( result ), == , col2_length + 1 );
     g_assert_cmpint( get_referring_object_list_struct.refers_to_object_call_count, == , col2_length + 1 );
     g_assert_cmpint( get_referring_object_list_struct.get_typed_referring_object_list_count, == , 2 );
